@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,8 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.dataflow.v1beta3",
@@ -42,13 +43,13 @@ class TopologyConfig(proto.Message):
     computations and their sharded locations.
 
     Attributes:
-        computations (Sequence[google.cloud.dataflow_v1beta3.types.ComputationTopology]):
+        computations (MutableSequence[google.cloud.dataflow_v1beta3.types.ComputationTopology]):
             The computations associated with a streaming
             Dataflow job.
-        data_disk_assignments (Sequence[google.cloud.dataflow_v1beta3.types.DataDiskAssignment]):
+        data_disk_assignments (MutableSequence[google.cloud.dataflow_v1beta3.types.DataDiskAssignment]):
             The disks assigned to a streaming Dataflow
             job.
-        user_stage_to_computation_name_map (Sequence[google.cloud.dataflow_v1beta3.types.TopologyConfig.UserStageToComputationNameMapEntry]):
+        user_stage_to_computation_name_map (MutableMapping[str, str]):
             Maps user stage names to stable computation
             names.
         forwarding_key_bits (int):
@@ -58,17 +59,29 @@ class TopologyConfig(proto.Message):
             Version number for persistent state.
     """
 
-    computations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="ComputationTopology",
+    computations: MutableSequence["ComputationTopology"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="ComputationTopology",
     )
-    data_disk_assignments = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="DataDiskAssignment",
+    data_disk_assignments: MutableSequence["DataDiskAssignment"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="DataDiskAssignment",
     )
-    user_stage_to_computation_name_map = proto.MapField(
-        proto.STRING, proto.STRING, number=3,
+    user_stage_to_computation_name_map: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
+    forwarding_key_bits: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    persistent_state_version: int = proto.Field(
+        proto.INT32,
+        number=5,
     )
-    forwarding_key_bits = proto.Field(proto.INT32, number=4,)
-    persistent_state_version = proto.Field(proto.INT32, number=5,)
 
 
 class PubsubLocation(proto.Message):
@@ -78,12 +91,10 @@ class PubsubLocation(proto.Message):
     Attributes:
         topic (str):
             A pubsub topic, in the form of
-            "pubsub.googleapis.com/topics/<project-
-            id>/<topic-name>".
+            "pubsub.googleapis.com/topics/<project-id>/<topic-name>".
         subscription (str):
             A pubsub subscription, in the form of
-            "pubsub.googleapis.com/subscriptions/<project-
-            id>/<subscription-name>".
+            "pubsub.googleapis.com/subscriptions/<project-id>/<subscription-name>".
         timestamp_label (str):
             If set, contains a pubsub label from which to
             extract record timestamps. If left empty, record
@@ -93,8 +104,8 @@ class PubsubLocation(proto.Message):
             extract record ids. If left empty, record
             deduplication will be strictly best effort.
         drop_late_data (bool):
-            Indicates whether the pipeline allows late-
-            rriving data.
+            Indicates whether the pipeline allows
+            late-arriving data.
         tracking_subscription (str):
             If set, specifies the pubsub subscription
             that will be used for tracking custom time
@@ -104,13 +115,34 @@ class PubsubLocation(proto.Message):
             pubsub attributes.
     """
 
-    topic = proto.Field(proto.STRING, number=1,)
-    subscription = proto.Field(proto.STRING, number=2,)
-    timestamp_label = proto.Field(proto.STRING, number=3,)
-    id_label = proto.Field(proto.STRING, number=4,)
-    drop_late_data = proto.Field(proto.BOOL, number=5,)
-    tracking_subscription = proto.Field(proto.STRING, number=6,)
-    with_attributes = proto.Field(proto.BOOL, number=7,)
+    topic: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    subscription: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    timestamp_label: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    id_label: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    drop_late_data: bool = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    tracking_subscription: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    with_attributes: bool = proto.Field(
+        proto.BOOL,
+        number=7,
+    )
 
 
 class StreamingStageLocation(proto.Message):
@@ -123,7 +155,10 @@ class StreamingStageLocation(proto.Message):
             streaming Dataflow job.
     """
 
-    stream_id = proto.Field(proto.STRING, number=1,)
+    stream_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class StreamingSideInputLocation(proto.Message):
@@ -138,8 +173,14 @@ class StreamingSideInputLocation(proto.Message):
             input is stored.
     """
 
-    tag = proto.Field(proto.STRING, number=1,)
-    state_family = proto.Field(proto.STRING, number=2,)
+    tag: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_family: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CustomSourceLocation(proto.Message):
@@ -150,36 +191,66 @@ class CustomSourceLocation(proto.Message):
             Whether this source is stateful.
     """
 
-    stateful = proto.Field(proto.BOOL, number=1,)
+    stateful: bool = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 class StreamLocation(proto.Message):
     r"""Describes a stream of data, either as input to be processed
     or as output of a streaming Dataflow job.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         streaming_stage_location (google.cloud.dataflow_v1beta3.types.StreamingStageLocation):
             The stream is part of another computation
             within the current streaming Dataflow job.
+
+            This field is a member of `oneof`_ ``location``.
         pubsub_location (google.cloud.dataflow_v1beta3.types.PubsubLocation):
             The stream is a pubsub stream.
+
+            This field is a member of `oneof`_ ``location``.
         side_input_location (google.cloud.dataflow_v1beta3.types.StreamingSideInputLocation):
             The stream is a streaming side input.
+
+            This field is a member of `oneof`_ ``location``.
         custom_source_location (google.cloud.dataflow_v1beta3.types.CustomSourceLocation):
             The stream is a custom source.
+
+            This field is a member of `oneof`_ ``location``.
     """
 
-    streaming_stage_location = proto.Field(
-        proto.MESSAGE, number=1, oneof="location", message="StreamingStageLocation",
+    streaming_stage_location: "StreamingStageLocation" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        oneof="location",
+        message="StreamingStageLocation",
     )
-    pubsub_location = proto.Field(
-        proto.MESSAGE, number=2, oneof="location", message="PubsubLocation",
+    pubsub_location: "PubsubLocation" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="location",
+        message="PubsubLocation",
     )
-    side_input_location = proto.Field(
-        proto.MESSAGE, number=3, oneof="location", message="StreamingSideInputLocation",
+    side_input_location: "StreamingSideInputLocation" = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        oneof="location",
+        message="StreamingSideInputLocation",
     )
-    custom_source_location = proto.Field(
-        proto.MESSAGE, number=4, oneof="location", message="CustomSourceLocation",
+    custom_source_location: "CustomSourceLocation" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        oneof="location",
+        message="CustomSourceLocation",
     )
 
 
@@ -194,8 +265,14 @@ class StateFamilyConfig(proto.Message):
             operation.
     """
 
-    state_family = proto.Field(proto.STRING, number=1,)
-    is_read = proto.Field(proto.BOOL, number=2,)
+    state_family: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    is_read: bool = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
 
 
 class ComputationTopology(proto.Message):
@@ -206,25 +283,43 @@ class ComputationTopology(proto.Message):
             The system stage name.
         computation_id (str):
             The ID of the computation.
-        key_ranges (Sequence[google.cloud.dataflow_v1beta3.types.KeyRangeLocation]):
+        key_ranges (MutableSequence[google.cloud.dataflow_v1beta3.types.KeyRangeLocation]):
             The key ranges processed by the computation.
-        inputs (Sequence[google.cloud.dataflow_v1beta3.types.StreamLocation]):
+        inputs (MutableSequence[google.cloud.dataflow_v1beta3.types.StreamLocation]):
             The inputs to the computation.
-        outputs (Sequence[google.cloud.dataflow_v1beta3.types.StreamLocation]):
+        outputs (MutableSequence[google.cloud.dataflow_v1beta3.types.StreamLocation]):
             The outputs from the computation.
-        state_families (Sequence[google.cloud.dataflow_v1beta3.types.StateFamilyConfig]):
+        state_families (MutableSequence[google.cloud.dataflow_v1beta3.types.StateFamilyConfig]):
             The state family values.
     """
 
-    system_stage_name = proto.Field(proto.STRING, number=1,)
-    computation_id = proto.Field(proto.STRING, number=5,)
-    key_ranges = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="KeyRangeLocation",
+    system_stage_name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    inputs = proto.RepeatedField(proto.MESSAGE, number=3, message="StreamLocation",)
-    outputs = proto.RepeatedField(proto.MESSAGE, number=4, message="StreamLocation",)
-    state_families = proto.RepeatedField(
-        proto.MESSAGE, number=7, message="StateFamilyConfig",
+    computation_id: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    key_ranges: MutableSequence["KeyRangeLocation"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="KeyRangeLocation",
+    )
+    inputs: MutableSequence["StreamLocation"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="StreamLocation",
+    )
+    outputs: MutableSequence["StreamLocation"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message="StreamLocation",
+    )
+    state_families: MutableSequence["StateFamilyConfig"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=7,
+        message="StateFamilyConfig",
     )
 
 
@@ -255,11 +350,26 @@ class KeyRangeLocation(proto.Message):
             in the worker local filesystem.
     """
 
-    start = proto.Field(proto.STRING, number=1,)
-    end = proto.Field(proto.STRING, number=2,)
-    delivery_endpoint = proto.Field(proto.STRING, number=3,)
-    data_disk = proto.Field(proto.STRING, number=5,)
-    deprecated_persistent_directory = proto.Field(proto.STRING, number=4,)
+    start: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    end: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    delivery_endpoint: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    data_disk: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    deprecated_persistent_directory: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class MountedDataDisk(proto.Message):
@@ -274,7 +384,10 @@ class MountedDataDisk(proto.Message):
             "myproject-1014-104817-4c2-harness-0-disk-1".
     """
 
-    data_disk = proto.Field(proto.STRING, number=1,)
+    data_disk: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DataDiskAssignment(proto.Message):
@@ -285,7 +398,7 @@ class DataDiskAssignment(proto.Message):
             VM instance name the data disks mounted to,
             for example
             "myproject-1014-104817-4c2-harness-0".
-        data_disks (Sequence[str]):
+        data_disks (MutableSequence[str]):
             Mounted data disks. The order is important a
             data disk's 0-based index in this list defines
             which persistent directory the disk is mounted
@@ -295,8 +408,14 @@ class DataDiskAssignment(proto.Message):
             }.
     """
 
-    vm_instance = proto.Field(proto.STRING, number=1,)
-    data_disks = proto.RepeatedField(proto.STRING, number=2,)
+    vm_instance: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    data_disks: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class KeyRangeDataDiskAssignment(proto.Message):
@@ -319,9 +438,18 @@ class KeyRangeDataDiskAssignment(proto.Message):
             "myproject-1014-104817-4c2-harness-0-disk-1".
     """
 
-    start = proto.Field(proto.STRING, number=1,)
-    end = proto.Field(proto.STRING, number=2,)
-    data_disk = proto.Field(proto.STRING, number=3,)
+    start: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    end: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    data_disk: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class StreamingComputationRanges(proto.Message):
@@ -331,14 +459,21 @@ class StreamingComputationRanges(proto.Message):
     Attributes:
         computation_id (str):
             The ID of the computation.
-        range_assignments (Sequence[google.cloud.dataflow_v1beta3.types.KeyRangeDataDiskAssignment]):
+        range_assignments (MutableSequence[google.cloud.dataflow_v1beta3.types.KeyRangeDataDiskAssignment]):
             Data disk assignments for ranges from this
             computation.
     """
 
-    computation_id = proto.Field(proto.STRING, number=1,)
-    range_assignments = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="KeyRangeDataDiskAssignment",
+    computation_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    range_assignments: MutableSequence[
+        "KeyRangeDataDiskAssignment"
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="KeyRangeDataDiskAssignment",
     )
 
 
@@ -354,8 +489,14 @@ class StreamingApplianceSnapshotConfig(proto.Message):
             appliance state.
     """
 
-    snapshot_id = proto.Field(proto.STRING, number=1,)
-    import_state_endpoint = proto.Field(proto.STRING, number=2,)
+    snapshot_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    import_state_endpoint: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
